document.addEventListener('DOMContentLoaded', () => {
  const gamesContainer = document.getElementById('gamesContainer');
  const refreshBtn = document.querySelector('.refresh-btn');
  const dateDisplay = document.querySelector('.current-date');
  const prevBtn = document.querySelector('.prev');
  const nextBtn = document.querySelector('.next');
  
  let currentDate = new Date();
  
  function formatDate(date) {
    return date.toLocaleDateString('en-US', {
      weekday: 'long',
      year: 'numeric',
      month: 'long',
      day: 'numeric'
    });
  }
  
  function updateDateDisplay() {
    dateDisplay.textContent = formatDate(currentDate);
  }
  
  function createGameCard(game) {
    return `
      <div class="game-card">
        <div class="team">
          <span class="team-name">${game.homeTeam}</span>
          <span class="score">${game.homeScore}</span>
        </div>
        <div class="team">
          <span class="team-name">${game.awayTeam}</span>
          <span class="score">${game.awayScore}</span>
        </div>
        <div class="game-status">${game.status}</div>
      </div>
    `;
  }
  
  function fetchGames() {
    // Simulated API response
    const mockGames = [
      {
        homeTeam: 'Lakers',
        awayTeam: 'Warriors',
        homeScore: 115,
        awayScore: 110,
        status: 'Final'
      },
      {
        homeTeam: 'Celtics',
        awayTeam: 'Nets',
        homeScore: 98,
        awayScore: 95,
        status: 'Q4 2:30'
      },
      {
        homeTeam: 'Bucks',
        awayTeam: 'Heat',
        homeScore: 85,
        awayScore: 82,
        status: 'Q3 5:45'
      }
    ];
    
    gamesContainer.innerHTML = mockGames
      .map(game => createGameCard(game))
      .join('');
  }
  
  function refreshScores() {
    gamesContainer.innerHTML = '<div class="loading">Refreshing scores...</div>';
    setTimeout(fetchGames, 1000);
  }
  
  prevBtn.addEventListener('click', () => {
    currentDate.setDate(currentDate.getDate() - 1);
    updateDateDisplay();
    refreshScores();
  });
  
  nextBtn.addEventListener('click', () => {
    currentDate.setDate(currentDate.getDate() + 1);
    updateDateDisplay();
    refreshScores();
  });
  
  refreshBtn.addEventListener('click', refreshScores);
  
  // Initial load
  updateDateDisplay();
  fetchGames();
  
  // Auto-refresh every 30 seconds
  setInterval(fetchGames, 30000);
});